DynClientHook

Type Alias DynClientHook 

pub type DynClientHook = dyn ClientHook;
Type alias for dyn ClientHook. We define this here because so that generated code can avoid needing to refer to dyn types directly; in Rust 2015 the syntax for dyn types requires extra parentheses that trigger warnings in newer editions.