Rc

Type Alias Rc 

pub type Rc<T> = Rc<T>;
Type alias that allows us to avoid using alloc directly in generated code, which would require an extern crate alloc in the crate root.

Aliased Type

pub struct Rc<T> { /* private fields */ }