RawBrandedStructSchema

Struct RawBrandedStructSchema 

pub struct RawBrandedStructSchema {
    pub generic: &'static RawStructSchema,
    pub field_types: fn(u16) -> Type,
    pub annotation_types: fn(Option<u16>, u32) -> Type,
    pub type_id: TypeId,
}
A RawStructSchema with branding information, i.e. resolution of type parameters. To use one of this, you will usually want to convert it to a schema::StructSchema, which can be done via into().

Fields

generic: &'static RawStructSchema

The unbranded base schema.

field_types: fn(u16) -> Type

Map from field index (not ordinal) to Type.

annotation_types: fn(Option<u16>, u32) -> Type

Map from (maybe field index, annotation index) to the Type of the value held by that annotation.

type_id: TypeId

Used to compare schemas at runtime - the TypeId of the Owned struct that this schema describes, including its branding.