GeneratedCodeArena

Struct GeneratedCodeArena 

pub struct GeneratedCodeArena { /* private fields */ }
An arena designed for the specific case of reading messages from single-segment Word arrays in generated code, including constants and raw schema nodes. Performs bounds checking, so its constructor does not need to be marked unsafe. Does not enforce a read limit or a nesting limit.

Implementations

Source

impl GeneratedCodeArena

pub const fn new(words: &'static [Word]) -> Self