pub fn read_message<R>(
read: R,
options: ReaderOptions,
) -> Result<Reader<OwnedSegments>>where
R: Read,Expand description
Reads a serialized message from a stream with the provided options.
For optimal performance, read should be a buffered reader type.