pub fn write_message<W, A>(write: W, message: &Builder<A>) -> Result<()>Expand description
Writes the provided message to write.
For optimal performance, write should be a buffered writer. flush() will not be called on
the writer.
The only source of errors from this function are write.write_all() calls. If you pass in
a writer that never returns an error, then this function will never return an error.