pub struct NoAllocSegmentTableInfo {
pub segments_count: usize,
pub segment_table_length_bytes: usize,
pub total_segments_length_bytes: usize,
}Expand description
Information about a message read from its segment table.
Fields
segments_count: usizeThe number of segments in the message.
segment_table_length_bytes: usizeThe number of bytes in the segment table.
total_segments_length_bytes: usizeThe total number of bytes in all segments of the message.