Module serialize_packed

Module serialize_packed 

Reading and writing of messages using the packed stream encoding.

Functions

read_message
Reads a packed message from a stream using the provided options.
read_message_no_alloc
Like read_message(), but does not allocate.
try_read_message
Like read_message(), but returns None instead of an error if there are zero bytes left in read.
try_read_message_no_alloc
Like try_read_message(), but does not allocate.
write_message
Writes a packed message to a stream.