Module capability

Module capability 

Hooks for the RPC system.

Roughly corresponds to capability.h in the C++ implementation.

Structs

Client
An untyped client.
DispatchCallResult
The return value of Server::dispatch_call().
Params
The values of the parameters passed to a method call, as seen by the server.
Promise
A computation that might eventually resolve to a value of type T or to an error of type E. Dropping the promise cancels the computation.
RemotePromise
A promise for a result from a method call.
Request
A method call that has not been sent yet.
Response
A response from a method call, as seen by the client.
Results
The return values of a method, written in-place by the method body.
StreamingRequest
A method call that has not been sent yet.

Traits

FromClientHook
Trait implemented (via codegen) by all user-defined capability client types.
FromServer
Trait to track the relationship between generated Server traits and Client structs.
FromTypelessPipeline
Server
An untyped server.

Functions

get_resolved_cap
Gets the “resolved” version of a capability. One place this is useful is for pre-resolving the argument to capnp_rpc::CapabilityServerSet::get_local_server_of_resolved().

Type Aliases

DynClientHook
Type alias for dyn ClientHook. We define this here because so that generated code can avoid needing to refer to dyn types directly; in Rust 2015 the syntax for dyn types requires extra parentheses that trigger warnings in newer editions.
Rc
Type alias that allows us to avoid using alloc directly in generated code, which would require an extern crate alloc in the crate root.