pub struct Results<T> {
pub marker: PhantomData<T>,
pub hook: Box<dyn ResultsHook>,
}Expand description
The return values of a method, written in-place by the method body.
Fields
marker: PhantomData<T>hook: Box<dyn ResultsHook>Implementations
Sourceimpl<T> Results<T>where
T: Owned,
impl<T> Results<T>where
T: Owned,
pub fn new(hook: Box<dyn ResultsHook>) -> Self
pub fn get(&mut self) -> T::Builder<'_>
pub fn set(&mut self, other: T::Reader<'_>) -> Result<()>
Sourcepub fn set_pipeline(&mut self) -> Result<()>
pub fn set_pipeline(&mut self) -> Result<()>
Call this method to signal that all of the capabilities have been filled in for this
Results and that pipelined calls should be allowed to start using those capabilities.
(Usually pipelined calls are enqueued until the initial call completes.)