Builder

Struct Builder 

pub struct Builder<A>
where A: Allocator,
{ /* private fields */ }
A container used to build a message.

Implementations

Source

impl<A> Builder<A>
where A: Allocator,

pub fn new(allocator: A) -> Self

pub fn init_root<'a, T: FromPointerBuilder<'a>>(&'a mut self) -> T

Initializes the root as a value of the given type.

pub fn initn_root<'a, T: FromPointerBuilder<'a>>(&'a mut self, length: u32) -> T

Initializes the root as a value of the given list type, with the given length.

pub fn get_root<'a, T: FromPointerBuilder<'a>>(&'a mut self) -> Result<T>

Gets the root, interpreting it as the given type.

pub fn get_root_as_reader<'a, T: FromPointerReader<'a>>(&'a self) -> Result<T>

pub fn set_root<T: Owned>(&mut self, value: impl SetterInput<T>) -> Result<()>

Sets the root to a deep copy of the given value.

pub fn set_root_canonical<T: Owned>( &mut self, value: impl SetterInput<T>, ) -> Result<()>

Sets the root to a canonicalized version of value. If this was the first action taken on this Builder, then a subsequent call to get_segments_for_output() should return a single segment, containing the full canonicalized message.

pub fn get_segments_for_output(&self) -> OutputSegments<'_>

pub fn into_reader(self) -> Reader<Self>

pub fn into_typed<T: Owned>(self) -> TypedBuilder<T, A>

pub fn into_allocator(self) -> A

Retrieves the underlying Allocator, deallocating all currently-allocated segments.

pub fn size_in_words(&self) -> usize

Source

impl Builder<HeapAllocator>

pub fn new_default() -> Self

Constructs a new message::Builder<HeapAllocator> whose first segment has length SUGGESTED_FIRST_SEGMENT_WORDS.