pub trait PrimitiveElement {
// Required methods
fn get(list_reader: &ListReader<'_>, index: ElementCount32) -> Self;
fn get_from_builder(
list_builder: &ListBuilder<'_>,
index: ElementCount32,
) -> Self;
fn set(list_builder: &ListBuilder<'_>, index: ElementCount32, value: Self);
fn element_size() -> ElementSize;
}Expand description
An element that can be stored in a primitive_list.
Required Methods
Sourcefn get(list_reader: &ListReader<'_>, index: ElementCount32) -> Self
fn get(list_reader: &ListReader<'_>, index: ElementCount32) -> Self
Gets the element at position index. Panics if the index is out of bounds.
Sourcefn get_from_builder(
list_builder: &ListBuilder<'_>,
index: ElementCount32,
) -> Self
fn get_from_builder( list_builder: &ListBuilder<'_>, index: ElementCount32, ) -> Self
Gets the element at position index. Panics if the index is out of bounds.
Sourcefn set(list_builder: &ListBuilder<'_>, index: ElementCount32, value: Self)
fn set(list_builder: &ListBuilder<'_>, index: ElementCount32, value: Self)
Sets to element at position index to be value. Panics if the index is out of bounds.
Sourcefn element_size() -> ElementSize
fn element_size() -> ElementSize
Returns the size of an individual element.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".