Reading and writing of messages using the packed stream encoding.
Functions
- read_
message - Reads a packed message from a stream using the provided options.
- read_
message_ no_ alloc - Like read_message(), but does not allocate.
- try_
read_ message - Like read_message(), but returns None instead of an error if there are zero bytes left in
read. - try_
read_ message_ no_ alloc - Like try_read_message(), but does not allocate.
- write_
message - Writes a packed message to a stream.